==> dagger-compiler-2.51.1-sources.jar: dagger/internal/codegen/binding/AutoValue_ModuleDescriptor.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.base.ModuleKind;
import java.lang.Boolean;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_ModuleDescriptor extends $AutoValue_ModuleDescriptor {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile ImmutableSet<BindingDeclaration> allBindingDeclarations;

  AutoValue_ModuleDescriptor(XTypeElement moduleElement$,
      ImmutableSet<ContributionBinding> bindings$,
      ImmutableSet<MultibindingDeclaration> multibindingDeclarations$,
      ImmutableSet<SubcomponentDeclaration> subcomponentDeclarations$,
      ImmutableSet<DelegateDeclaration> delegateDeclarations$,
      ImmutableSet<OptionalBindingDeclaration> optionalDeclarations$, ModuleKind kind$,
      Boolean isImplicitlyIncluded$) {
    super(moduleElement$, bindings$, multibindingDeclarations$, subcomponentDeclarations$, delegateDeclarations$, optionalDeclarations$, kind$, isImplicitlyIncluded$);
  }

  @Override
  public ImmutableSet<BindingDeclaration> allBindingDeclarations() {
    if (allBindingDeclarations == null) {
      synchronized (this) {
        if (allBindingDeclarations == null) {
          allBindingDeclarations = super.allBindingDeclarations();
          if (allBindingDeclarations == null) {
            throw new NullPointerException("allBindingDeclarations() cannot return null");
          }
        }
      }
    }
    return allBindingDeclarations;
  }
}

==> dagger-compiler-2.57-sources.jar: dagger/internal/codegen/binding/AutoValue_ModuleDescriptor.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.base.ModuleKind;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_ModuleDescriptor extends $AutoValue_ModuleDescriptor {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile ImmutableSet<Declaration> allBindingDeclarations;

  AutoValue_ModuleDescriptor(XTypeElement moduleElement$,
      ImmutableSet<ContributionBinding> bindings$,
      ImmutableSet<MultibindingDeclaration> multibindingDeclarations$,
      ImmutableSet<SubcomponentDeclaration> subcomponentDeclarations$,
      ImmutableSet<DelegateDeclaration> delegateDeclarations$,
      ImmutableSet<OptionalBindingDeclaration> optionalDeclarations$, ModuleKind kind$,
      boolean isImplicitlyIncluded$) {
    super(moduleElement$, bindings$, multibindingDeclarations$, subcomponentDeclarations$, delegateDeclarations$, optionalDeclarations$, kind$, isImplicitlyIncluded$);
  }

  @Override
  public ImmutableSet<Declaration> allBindingDeclarations() {
    if (allBindingDeclarations == null) {
      synchronized (this) {
        if (allBindingDeclarations == null) {
          allBindingDeclarations = super.allBindingDeclarations();
          if (allBindingDeclarations == null) {
            throw new NullPointerException("allBindingDeclarations() cannot return null");
          }
        }
      }
    }
    return allBindingDeclarations;
  }
}
